# Table of Contents

- [application-rationalization-enrich-data](<./application-rationalization-enrich-data.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 3: Enrich Data](<./Step-3-Enrich-Data.md>)
  - [Datapoints for Rationalization](<./Step-3-Enrich-Data/Datapoints-for-Rationalization.md>)
  - [Collect Data from Experts](<./Step-3-Enrich-Data/Collect-Data-from-Experts.md>)
  - [Collect Data from Integrations](<./Step-3-Enrich-Data/Collect-Data-from-Integrations.md>)
  - [Total Cost of Ownership](<./Step-3-Enrich-Data/Total-Cost-of-Ownership.md>)
  - [Calculate the Total Cost of Ownership for Applications](<./Step-3-Enrich-Data/Calculate-the-Total-Cost-of-Ownership-for-Applications.md>)
  - [Allocate Application Cost](<./Step-3-Enrich-Data/Allocate-Application-Cost.md>)
  - [Custom Cost Calculations](<./Step-3-Enrich-Data/Custom-Cost-Calculations.md>)
